BitwuzlaResult
==============

- enum :cpp:enum:`BitwuzlaResult`
- :cpp:func:`bitwuzla_result_to_string()`

----

.. doxygenenum:: BitwuzlaResult
    :project: Bitwuzla_c

----

.. doxygenfunction:: bitwuzla_result_to_string
    :project: Bitwuzla_c
